/*
 * Author:          Patrick-Christopher Mattulat
 * Company:         Lynar Studios
 * E-Mail:          webmaster@lynarstudios.com
 * Created:         2021-04-30
 * Changed:         2024-09-11
 *
 * */

#ifndef LS_STD_INCOMPLETE_JSON_EXCEPTION_HPP
#define LS_STD_INCOMPLETE_JSON_EXCEPTION_HPP

#include <ls-std/core/exception/Exception.hpp>
#include <ls-std/os/dynamic-goal.hpp>
#include <string>

/*
 * @doc: class(name: 'IncompleteJsonException', package: 'core')
 * @doc: core.IncompleteJsonException.description('This exception can be thrown when a passed JSON is incomplete - e.g. if a key is missing.')
 * */

namespace ls::std::core
{
  class LS_STD_DYNAMIC_GOAL IncompleteJsonException : public ls::std::core::Exception
  {
    public:

      IncompleteJsonException();
      explicit IncompleteJsonException(const ::std::string &_message);
      ~IncompleteJsonException() noexcept override;

      [[nodiscard]] const char *what() const noexcept override;
  };
}

#endif
